;;; -*-emacs-lisp-*-
;;; ====================================================================
;;;  @Emacs-Lisp-file{
;;;     author          = "Nelson H. F. Beebe",
;;;     version         = "1.00",
;;;     date            = "05 June 2002",
;;;     time            = "09:18:17 MDT",
;;;     filename        = "javadoc-extra.el",
;;;     address         = "Center for Scientific Computing
;;;                        University of Utah
;;;                        Department of Mathematics, 110 LCB
;;;                        155 S 1400 E RM 233
;;;                        Salt Lake City, UT 84112-0090
;;;                        USA",
;;;     telephone       = "+1 801 581 5254",
;;;     FAX             = "+1 801 585 1640, +1 801 581 4148",
;;;     URL             = "http://www.math.utah.edu/~beebe",
;;;     checksum        = "54144 175 812 6861",
;;;     email           = "beebe@math.utah.edu, beebe@acm.org,
;;;                       beebe@computer.org, beebe@ieee.org (Internet)",
;;;     codetable       = "ISO/ASCII",
;;;     keywords        = "Emacs Lisp; javadoc HTML wrappers",
;;;     supported       = "yes",
;;;     docstring       = "This file is a collection of simple emacs
;;;                        functions for adding limited javadoc HTML
;;;                        wrappers around words.
;;;
;;;                        The checksum field above contains a CRC-16
;;;                        checksum as the first value, followed by the
;;;                        equivalent of the standard UNIX wc (word
;;;                        count) utility output of lines, words, and
;;;                        characters.  This is produced by Robert
;;;                        Solovay's checksum utility.",
;;;  }
;;; ====================================================================

;;; javadoc-extra.el -- additional GNU Emacs editing support for javadoc comments

;; Author: Nelson H. F. Beebe <beebe@math.utah.edu>
;; Created: 05-Jun-2002
;; Version: 1.00
;; Keywords: Emacs Lisp; javadoc HTML wrappers

;; Copyright (C) 2002 Free Software Foundation, Inc.

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Commentary:

;;; Change log:

;; [1.00] Wed Jun  5 09:21:33 2002
;; Original version.

(provide 'javadoc-extra)

(defconst javadoc-extra-version "1.00 [05-Jun-2002]"
  "Version number and date of the javadoc-extra.el library.")

(defun internal-javadoc-default (value default-value)
  "Return a non-nil value from VALUE, current-prefix-arg, or
DEFAULT-VALUE, in that order.  Do

   (setq argvar (internal-javadoc-default argvar 23))

to set &optional argvar to (a) argvar, if argvar is non-nil, else (b)
current-prefix-arg, if that is non-nil, else (c) 23.  This simplifies
optional argument assignment in many functions."
  (cond
   ((not (null value))			;do nothing if explicit arg
    value)
   ((not (null current-prefix-arg))	;else use prefix arg if any
    (prefix-numeric-value current-prefix-arg))
   (t					;else no arg at all, so use default
    default-value)
   )
  )

(defun javadoc-add-b-markup ()
  "Add javadoc <b>...</b> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "b" word-count)))

(defun javadoc-add-code-markup ()
  "Add javadoc <code>...</code> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "code" word-count)))

(defun javadoc-add-em-markup ()
  "Add javadoc <em>...</em> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "em" word-count)))

(defun javadoc-add-i-markup ()
  "Add javadoc <i>...</i> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "i" word-count)))

(defun javadoc-add-sub-markup ()
  "Add javadoc <sub>...</sub> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "sub" word-count)))

(defun javadoc-add-sup-markup ()
  "Add javadoc <sup>...</sup> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "sup" word-count)))

(defun javadoc-add-tt-markup ()
  "Add javadoc <tt>...</tt> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "tt" word-count)))

(defun javadoc-add-var-markup ()
  "Add javadoc <var>...</var> markup around the next ARG (default 1)
words, leaving point after the marked up text."
  (interactive)
  (let ((word-count))
    (setq word-count (internal-javadoc-default word-count 1))
    (javadoc-add-xxx-markup "var" word-count)))

(defun javadoc-add-xxx-markup (name word-count)
  "Add javadoc <name>...</name> markup around the next word-count
words, leaving point after the marked up text."
  (forward-word word-count)
  (backward-word word-count)
  (insert "<" name ">")
  (forward-word word-count)
  (insert "</" name ">"))

;;; The C-c prefix is defined in Java mode, but none of these bindings
;;; is used by it, so nothing is lost or hidden by them.
(local-set-key "\C-cb" 'javadoc-add-b-markup)
(local-set-key "\C-cc" 'javadoc-add-code-markup)
(local-set-key "\C-ce" 'javadoc-add-em-markup)
(local-set-key "\C-ci" 'javadoc-add-i-markup)
(local-set-key "\C-c_" 'javadoc-add-sub-markup)
(local-set-key "\C-c^" 'javadoc-add-sup-markup)
(local-set-key "\C-ct" 'javadoc-add-tt-markup)
(local-set-key "\C-cv" 'javadoc-add-var-markup)
